1.14.1 — Rucio 1.2 documentation

# 1.14.1

## General

### Features

- Release management: Create a script which automatically compiles release notes based on github milestones #213

### Enhancements

- Infrastructure: Restructure Dockerfile #246
- RSE Manager: root: force GSI authentication #83
- Release management: Removing duplicate packages in pip-requires #214
- Release management: Removed kerberos from requirements to enable buildthedocs #237
- Testing: Fix pylint tests on travis #209
- Testing: remove instant client installation from travis dockerfile #258

### Bugs

- Core & Internals: db: fix outer join read lock for PostgreSQL #262
- Core & Internals: lifetime: circular dependency #77
- check_quota probe does not create quota for new SCRATCHDISKS for old accounts #199
- Release management: Remove import rucio from webui setup.py #227

## Clients

### Enhancements

- Clients: Add eventType and usrDN parameters to CLI up/download #211

### Bugs

- Clients: Error when adding dataset with lifetime #244